@@ -2,7 +2,7 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
-from pinecone.network.zmq import ZMQServlet, Socket, SocketType, entrypoints
+from pinecone.network.zmq import Socket, SocketType, entrypoints
 from pinecone.network.zmq.spec import ServletSpec
 from pinecone.utils import load_hub_service, constants
 from pinecone import functions
