@@ -25,7 +25,8 @@ class HubModel(abc.ABC):
         self.servlet = None
         self.docker_host = docker_host
         self.executor = None
-        self.logger_loop = None
+        self.log_task = None
+        self.dns_tasks = []
         self.config = config or {}
         super().__init__(**kwargs)
         self.config['image'] = image
@@ -76,21 +77,22 @@ class HubModel(abc.ABC):
         command = ['python3', '-m', 'pinecone.functions.model', *self.to_args()]
         self.docker_client = docker.from_env()
         self.container = self.docker_client.containers.run(self.image_uri(), command, ports=ports, detach=True,
-                                                           environment=['PYTHONUNBUFFERED==1'])
+                                                           environment=['PYTHONUNBUFFERED==1',
+                                                                        'DD_TRACING_ENABLED=False'])
         time.sleep(1)
-        try:
-            loop = asyncio.get_event_loop()
-            self.logger_loop = loop.create_task(self.get_container_logs())
-        except RuntimeError:
-            # asyncio.run(self.get_container_logs())
-            logger.warning('no event loop running, not logging docker')
+        loop = asyncio.get_event_loop()
+        self.log_task = loop.create_task(self.get_container_logs())
+        self.dns_tasks = self.servlet.refresh_dns()
+
 
     def stop(self):
         if self.container:
             self.container.stop()
             self.container = None
-        if self.logger_loop:
-            self.logger_loop.cancel()
+        if self.log_task:
+            self.log_task.cancel()
+        for task in self.dns_tasks:
+            task.cancel()
 
     def __enter__(self):
         self.start()
