@@ -19,7 +19,10 @@ class CosineRanker(Ranker):
         return x / xx_row_norms[:, np.newaxis]
 
     def norm(self, q):
-        return q / np.sqrt(np.einsum('ij,ij->i', q, q))
+        norm = np.sqrt(np.einsum('ij,ij->i', q, q))
+        if norm == 0:
+            return q
+        return q / norm
 
     def sim_cosine(self, x, u):
         norm_x = np.sqrt(np.einsum('i,i->', x, x))
